==> v4mail-0.1.9.tar.gz: v4mail-0.1.9/v4mail/server.py <==
"""\
python package to send html and non html gmails
visit https://pypi.org/project/v4mail/ for more information
"""
__author__='vkv-onfire'
import smtplib, ssl
import socket
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
class html:
	def __init__(self, email, password):
		self.email=email
		self.password=password
	def add(self, subject, message):
		self.subject=subject
		self.message=message
	def sendto(self, recvr):
		body = MIMEMultipart("alternative")
		body['Subject'] = self.subject
		body['From'] = self.email
		body['To'] = recvr
		ptext='    GMail    '
		HTML = self.message
		p1=MIMEText(ptext, "plain")
		p2=MIMEText(HTML, 'html')
		body.attach(p1)
		body.attach(p2)
		self.content=body
		self.rcvr=recvr
	def send(self, echo=True):
		if echo==True:
			def out(arg):
				print(arg)
		elif echo==False:
			def out(arg):
				pass
		else:
			print('echo means output printing it should be True or False')
		out('starting mail server')
		try:
			context = ssl.create_default_context()
			with smtplib.SMTP_SSL("smtp.gmail.com", 465, context=context) as server:
				out('server started')
				out('logging to gmail')
				server.login(self.email, self.password)
				out('succesfully logged in')
				out('sending gmail')
				server.sendmail(
					self.email, self.rcvr, self.content.as_string()
					)
				out('succesfully sended gmail')
				return True
		except smtplib.SMTPAuthenticationError:
			print('invalid username and password')
			print('please visit https://pypi.org/project/v4mail/')
			return False
		except socket.gaierror:
			print('please check your internet connection and try again')
			return False
		except Exception as error:
			print('error occured')
			print('unknown error')
			print('logs:')
			print(error)
			return False
class text:
	def __init__(self, email, password):
		self.email=email
		self.password=password
	def add(self, subject, text):
		self.subject=subject
		self.text=text
	def send(self, reciever, echo=True):
		if echo==True:
			def out(arg):
				print(arg)
		elif echo==False:
			def out(arg):
				pass
		else:
			print('echo means output printing it should be True or False')
		out('mail server started')
		
		email=self.email
		password=self.password
		try:
			subject=self.subject
		except:
			subject=''
		try:
			body=self.text
		except:
			body=''
		try:
			server=smtplib.SMTP('smtp.gmail.com', 587)
			server.starttls()
			try:
				out('logging to gmail')
				server.login(email, password)
				out('succesfully logged to gmail')
			except:
				print('invalid username and password')
				print('visit https://pypi.org/project/v4mail/ for more information')
			try:
				out('sending mail')
				cont='Subject: '+str(subject)+'\n\n'+body
				server.sendmail(email, reciever, cont)
			
				out('succesfully sended')
				server.quit()
				out('tasks finished')
				return True
			except:
				print('error on sending')
				return False
		except Exception:
			print('error')
			return False

==> v4mail-0.2.6.tar.gz: v4mail-0.2.6/v4mail/server.py <==
"""\
python package to send html and non html gmails
visit https://pypi.org/project/v4mail/ for more information
"""
__author__='vkv-onfire'
import smtplib, ssl
import socket
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
import .__init__ as v4mail
class html:
	def __init__(self, email=v4mail.email(), password=v4mail.password()):
		self.email=email
		self.password=password
	def add(self, subject, message):
		self.subject=subject
		self.message=message
	def sendto(self, recvr):
		body = MIMEMultipart("alternative")
		body['Subject'] = self.subject
		body['From'] = self.email
		body['To'] = recvr
		ptext='    GMail    '
		HTML = self.message
		p1=MIMEText(ptext, "plain")
		p2=MIMEText(HTML, 'html')
		body.attach(p1)
		body.attach(p2)
		self.content=body
		self.rcvr=recvr
	def send(self, echo=True):
		if echo==True:
			def out(arg):
				print(arg)
		elif echo==False:
			def out(arg):
				pass
		else:
			print('echo means output printing it should be True or False')
		out('starting mail server')
		try:
			context = ssl.create_default_context()
			with smtplib.SMTP_SSL("smtp.gmail.com", 465, context=context) as server:
				out('server started')
				out('logging to gmail')
				server.login(self.email, self.password)
				out('succesfully logged in')
				out('sending gmail')
				server.sendmail(
					self.email, self.rcvr, self.content.as_string()
					)
				out('succesfully sended gmail')
				return True
		except smtplib.SMTPAuthenticationError:
			print('invalid username and password')
			print('please visit https://pypi.org/project/v4mail/')
			return False
		except socket.gaierror:
			print('please check your internet connection and try again')
			return False
		except Exception as error:
			print('error occured')
			print('unknown error')
			print('logs:')
			print(error)
			return False
class text:
	def __init__(self, email=v4mail.email(), password=v4mail.password()):
		self.email=email
		self.password=password
	def add(self, subject, text):
		self.subject=subject
		self.text=text
	def send(self, reciever, echo=True):
		if echo==True:
			def out(arg):
				print(arg)
		elif echo==False:
			def out(arg):
				pass
		else:
			print('echo means output printing it should be True or False')
		out('mail server started')
		
		email=self.email
		password=self.password
		try:
			subject=self.subject
		except:
			subject=''
		try:
			body=self.text
		except:
			body=''
		try:
			server=smtplib.SMTP('smtp.gmail.com', 587)
			server.starttls()
			try:
				out('logging to gmail')
				server.login(email, password)
				out('succesfully logged to gmail')
			except:
				print('invalid username and password')
				print('visit https://pypi.org/project/v4mail/ for more information')
			try:
				out('sending mail')
				cont='Subject: '+str(subject)+'\n\n'+body
				server.sendmail(email, reciever, cont)
			
				out('succesfully sended')
				server.quit()
				out('tasks finished')
				return True
			except:
				print('error on sending')
				return False
		except Exception:
			print('error')
			return False
